@@ -1,23 +1,22 @@
 #' @title Direction Dependence Analysis: Independence Properties
 #' @description \code{dda.indep} evaluates asymmetries of predictor-error independence of
 #'              causally competing models (\code{y ~ x} vs. \code{x ~ y}).
-#'
 #' @param formula      Symbolic formula of the model to be tested or a \code{lm} object.
 #' @param pred         A character indicating the variable name of the predictor which serves as the outcome in the alternative model.
 #' @param data         An optional data frame containing the variables in the model (by default variables are taken from the environment which \code{dda.indep} is called from).
 #' @param nlfun        Either a numeric value or a function of .Primitive type used for non-linear correlation tests. When \code{nlfun} is numeric the value is used in a power transformation.
 #' @param hetero       A logical value indicating whether separate homoscedasticity tests (i.e., standard and robust Breusch-Pagan tests) should be computed.
-#' @param hsic.method  A character indicating the inference method for the Hilbert-Schmidt Independence Criterion (HSIC). Must be one of the four specifications \code{c("gamma", "eigenvalue", "boot", "permutation")}. \code{hsic.method = "gamma"}is the default.
+#' @param hsic.method  A character indicating the inference method for the Hilbert-Schmidt Independence Criterion (HSIC). Must be one of the four specifications \code{c("gamma", "eigenvalue", "bootstrap", "permutation")}. \code{hsic.method = "gamma"}is the default.
 #' @param diff         A logical value indicating whether differences in HSIC, Distance Correlation (dCor), and MI values should be computed. Bootstrap confidence intervals are computed using B bootstrap samples.
-#' @param B            Number of permutations for separate dCor tests and number of resamples if \code{hsic.method = c("boot", "permutation")} or \code{diff = TRUE}.
+#' @param B            Number of permutations for separate dCor tests and number of resamples if \code{hsic.method = c("bootstrap", "permutation")} or \code{diff = TRUE}.
 #' @param boot.type    A vector of character strings representing the type of bootstrap confidence intervals. Must be one of the two specifications \code{c("perc", "bca")}.\code{boot.type = "perc"} is the default.
 #' @param conf.level   Confidence level for bootstrap confidence intervals.
 #' @param parallelize  A logical value indicating whether bootstrapping is performed on multiple cores. Only used if \code{diff = TRUE}.
 #' @param cores        A numeric value indicating the number of cores. Only used if \code{parallelize = TRUE}.
 #'
-#' @returns An object of class \code{dda.indep} containing the results of 
+#' @returns An object of class \code{dda.indep} containing the results of
 #'          independence tests of Direction Dependence Analysis.
-#' 
+#'
 #' @references Wiedermann, W., & von Eye, A. (2025). \emph{Direction Dependence Analysis: Foundations and Statistical Methods}. Cambridge, UK: Cambridge University Press.
 #'
 #' @examples
@@ -150,7 +149,7 @@ dda.indep <- function(
 	if( !boot.type %in% c("bca", "perc") ) stop( "Unknown argument in boot.type." )
 
 	if( !is.null(hsic.method)){
-	    if (!hsic.method %in% c(NULL, "gamma", "boot", "permutation", "eigenvalue")) stop( "Unknown argument in hsic.method.")
+	    if (!hsic.method %in% c(NULL, "gamma", "bootstrap", "permutation", "eigenvalue")) stop( "Unknown argument in hsic.method.")
 	}
 
 	### --- prepare outcome, predictor, and model matrix for covariates
@@ -183,6 +182,7 @@ dda.indep <- function(
 
   ry <- lm.fit(X, y)$residuals
 	rx <- lm.fit(X, x)$residuals
+	#add logical indicator: if robust = TRUE
 
 	m.yx <- lm(ry ~ rx)
 	m.xy <- lm(rx ~ ry)
@@ -203,7 +203,7 @@ dda.indep <- function(
 	}
 
 
-	if(hsic.method %in% c("boot", "permutation")){
+	if(hsic.method %in% c("bootstrap", "permutation")){
 
 	   hsic.yx <- dHSIC::dhsic.test(rx, err.yx, method = hsic.method, kernel = "gaussian", B = B)
 	   hsic.xy <- dHSIC::dhsic.test(ry, err.xy, method = hsic.method, kernel = "gaussian", B = B)
@@ -271,7 +271,10 @@ dda.indep <- function(
 
 	    }
 
-      if( boot.type == "bca" && any( is.na( boot::empinf( boot.res ) ) ) ) stop("Acceleration constant cannot be calculated. Increase the number of resamples or use boot.type = 'perc'")
+      if( boot.type == "bca" && any( is.na( boot::empinf( boot.res ) ) ) ) {
+        warning("Acceleration constant cannot be calculated. Falling back to percentile bootstrap method. Consider increasing the number of resamples (B) for more stable results.", call. = FALSE)
+        boot.type <- "perc"
+      }
 
 	  suppressWarnings(boot.out <- lapply(as.list(1:3), function(i, boot.res) boot::boot.ci(boot.res, conf=conf.level, type=boot.type, t0=boot.res$t0[i], t=boot.res$t[,i]), boot.res=boot.res))
 
@@ -327,7 +330,7 @@ print.dda.indep <- function(x, ...){
 	 cat("Omnibus Independence Tests:", "\n")
 
 	 #if(x$hsic.method[1] == "gamma") cat("Hilbert-Schmidt Independence Criterion: Gamma-Approximation", "\n")
-	 #if(x$hsic.method[1] == "boot") cat(paste("Hilbert-Schmidt Independence Criterion: Bootstrap-Approximation", " (", x$hsic.method[2], " resamples)", sep = ""), "\n")
+	 #if(x$hsic.method[1] == "bootstrap") cat(paste("Hilbert-Schmidt Independence Criterion: Bootstrap-Approximation", " (", x$hsic.method[2], " resamples)", sep = ""), "\n")
 
 	 cat(paste("HSIC = ", round(x$hsic.yx$statistic, 4), ", p-value = ", round(x$hsic.yx$p.value, 4), sep = ""))
 	 cat("\n")
@@ -386,7 +389,7 @@ print.dda.indep <- function(x, ...){
 	 cat("Omnibus Independence Tests:", "\n")
 
 	 #if(x$hsic.method[1] == "gamma") cat("Hilbert-Schmidt Independence Criterion: Gamma-Approximation", "\n")
-	 #if(x$hsic.method[1] == "boot") cat(paste("Hilbert-Schmidt Independence Criterion: Bootstrap-Approximation", " (", x$hsic.method[2], " resamples)", sep = ""), "\n")
+	 #if(x$hsic.method[1] == "bootstrap") cat(paste("Hilbert-Schmidt Independence Criterion: Bootstrap-Approximation", " (", x$hsic.method[2], " resamples)", sep = ""), "\n")
 
 	 cat(paste("HSIC = ", round(x$hsic.xy$statistic, 4), ", p-value = ", round(x$hsic.xy$p.value, 4), sep = ""))
 	 cat("\n")
@@ -453,4 +456,3 @@ if(!is.null(x$out.diff)){
     }
 }
 
-
