@@ -1,6 +1,6 @@
 #' @title Direction Dependence Analysis: Residual Distributions
 #' @description \code{dda.resdist} evaluates patterns of asymmetry of error
-#'              distributions of causally competing models (\code{y ~ x} 
+#'              distributions of causally competing models (\code{y ~ x}
 #'              vs. \code{x ~ y}).
 #' @name dda.resdist
 #'
@@ -20,7 +20,7 @@
 #' @param conf.level  Confidence level for bootstrap confidence intervals.
 #' @param ...         Additional arguments to be passed to the function.
 #'
-#' @returns An object of class \code{ddaresdist} containing the results of  
+#' @returns An object of class \code{ddaresdist} containing the results of
 #'          direction dependence tests of error distributions.
 #'
 #' @examples
@@ -37,12 +37,12 @@
 #' @references Wiedermann, W., & von Eye, A. (2025). Direction Dependence Analysis: Foundations and Statistical Methods. Cambridge, UK: Cambridge University Press.
 #' @export
 #' @rdname dda.resdist
-dda.resdist <- function(formula, 
-                        pred = NULL, 
-                        data = list(), 
+dda.resdist <- function(formula,
+                        pred = NULL,
+                        data = list(),
                         B = 200,
-                        boot.type = "perc", 
-                        prob.trans = FALSE, 
+                        boot.type = "perc",
+                        prob.trans = FALSE,
                         conf.level = 0.95
                         ){
 
@@ -338,9 +338,20 @@ dda.resdist <- function(formula,
   ### --- run bootstrap confidence intervals
 
   if(B > 0){
-    suppressWarnings(boot.res <- boot::boot(dat, boot.diff, R = B, prob.trans = prob.trans))
-    if( boot.type == "bca" && any( is.na( boot::empinf( boot.res ) ) ) ) stop("Acceleration constant cannot be calculated. Increase the number of resamples or use boot.type = 'perc'")
-    suppressWarnings(boot.out <- lapply(as.list(1:7), function(i, boot.res) boot::boot.ci(boot.res, conf=conf.level, type=boot.type, t0=boot.res$t0[i], t=boot.res$t[,i]), boot.res=boot.res))
+    suppressWarnings(boot.res <- boot::boot(dat, boot.diff, R = B, prob.trans = prob.trans))    #
+
+    # if( boot.type == "bca" && any( is.na( boot::empinf( boot.res ) ) ) ) stop("Acceleration constant cannot be calculated. Increase the number of resamples or use boot.type = 'perc'")
+    # suppressWarnings(boot.out <- lapply(as.list(1:7), function(i, boot.res) boot::boot.ci(boot.res, conf=conf.level, type=boot.type, t0=boot.res$t0[i], t=boot.res$t[,i]), boot.res=boot.res))
+
+    if( boot.type == "bca"){
+      boot.out <- suppressWarnings( try(
+        lapply(as.list(1:7), function(i, boot.res) boot::boot.ci(boot.res, conf=conf.level, type="bca", t0=boot.res$t0[i], t=boot.res$t[,i]), boot.res=boot.res), silent = TRUE))
+      if (inherits(boot.out, "try-error")) { stop("Acceleration constant cannot be calculated. Increase the number of resamples or use boot.type = 'perc'") }
+    }
+
+    if( boot.type == "perc"){
+      suppressWarnings(boot.out <- lapply(as.list(1:7), function(i, boot.res) boot::boot.ci(boot.res, conf=conf.level, type="perc", t0=boot.res$t0[i], t=boot.res$t[,i]), boot.res=boot.res))
+    }
 
     names(boot.out) <- c("skew.diff", "kurt.diff", "cor12.diff", "cor13.diff", "RHS3", "RCC", "RHS4")
 
